@@ -195,8 +195,17 @@ def main():
 
     # Parse args
     args = parser.parse_args()
-    if args.level is not None and (args.level < 1 or args.level > bl3save.max_level):
-        raise argparse.ArgumentTypeError('Valid level range is 1 through {}'.format(bl3save.max_level))
+    if args.level is not None:
+        if args.level < 1 or args.level > bl3save.max_supported_level:
+            raise argparse.ArgumentTypeError('Valid level range is 1 through {} (currently known in-game max of {})'.format(
+                bl3save.max_supported_level,
+                bl3save.max_level,
+                ))
+        if args.level > bl3save.max_level:
+            print('WARNING: Setting character level to {}, when {} is the currently-known max'.format(
+                args.level,
+                bl3save.max_level,
+                ))
 
     # Expand any of our "all" unlock actions
     if 'all' in args.unlock:
@@ -226,6 +235,11 @@ def main():
     if args.item_levels:
         if args.item_levels < 1 or args.item_levels > 100:
             raise argparse.ArgumentTypeError('Valid item level range is 1 through 100')
+        if args.item_levels > bl3save.max_level:
+            print('WARNING: Setting item levels to {}, when {} is the currently-known max'.format(
+                args.item_levels,
+                bl3save.max_level,
+                ))
 
     # Check for overwrite warnings
     if os.path.exists(args.output_filename) and not args.force:
